#!/usr/bin/env python2.7
from moke import * #@UnusedWildImport

@task
def nodef_float(name):
    """
    - name(``float``)
    """
    print type(name)

@task
def nodef_path(name):
    """
    - name(``path``)
    """
    print type(name)

@task
def none_float(name=None):
    """
    - name(``float``)
    """
    print type(name)

@task
def none_path(name=None):
    """
    - name(``path``)
    """
    print type(name)

    

    
if __name__ == "__main__":
    task()



#!/usr/bin/env python2.7
from moke import * #@UnusedWildImport

@task
def sayhello(name=required):
    """
     - name(``str``)
    """
    log("executing hello task")
    stdout.write("hello %s\n" % name)

if __name__ == "__main__":
    task()



#!/usr/bin/env python2.7
from moke import * #@UnusedWildImport

@task
def sayhello(a,bc,d=1):
    """
     - a(``path``) a is legit 
     - bc(``path+``) bc is legit
     - d(``int``) some option
    """

if __name__ == "__main__":
    task("asa")



#!/usr/bin/env python2.7
from moke import *
import sys

@task
def fromdef_int(i=1):
     assert type(i) == int

@task
def fromdef_float(i=1.):
     assert type(i) == float

@task
def fromdef_path_r(i=stdin):
    assert type(i) == file
    assert i.mode == "r", i.mode

@task
def fromdef_path_w(i=stdout):
    assert type(i) == file
    assert i.mode == "w"

@task
def fromdoc_none_int(i=None):
    """
     - i(``int``) gets parsed!

    """
    assert type(i) == int, type(i)

# @task
# def fromdoc_none_float(i=None):
#     """
#     -i(float) gets parsed!
#     """
#     assert type(i) == float

# @task
# def fromdoc_pos_int(k):
#     """General docs.
#     -k(int) gets parsed!
#     More general docs.
#     """
#     assert type(k) == int

# @task
# def fromdoc_pos_2(j, k):
#     """General docs.
#     -k(int) gets parsed!
#     More general docs.
#     """
#     assert type(k) == int
#     assert type(j) == str

# @task
# def none():
#     pass

# @task
# def null():
#     log("null called")

# @task
# def nulldoc():
#     """
#     """

# @task
# def justdoc():
#     """ethio-jazz rules!
#     for ever!
#     """

# @task
# def nonedoc(j = None):
#     """
#     """

# @task
# def unktype(j = 1, zzz=17, a="Strrr"):
#     """
#     -j(sasalambada)
#     """
#     assert type(j) == int
#     assert type(a) == str

# @task
# def iptopt(ipt=stdin, opt=stdout):
#     #print ipt
#     with ipt as ipt, opt as opt:
#         for line in ipt:
#             cols = line.strip().split("\t")
#             opt.write("\t".join(cols[::-1]) + "\n")

# @task
# def filew(opt=stdout):
#     """
#     opt(file_w) A file to write
#     """
#     print repr(opt)


# @task
# def postype(a):
#     """
#     -a(int)
#     """
#     assert type(a) == int

# @task
# def deftype(a=7):
#     """
#     """
#     assert type(a) == int


@task
def greet(who, shout=False, times=1):
    """
    Sends greetings from moke.
    
     - who(str2) two persons to greet
     - shout(switch) triggers CAPS
    
    """
    greetings = ("Hello %s and %s!\n" % (who[0], who[1])) * times
    if shout:
        greetings = greetings.upper()
    print greetings.strip()
    log("greeted: %s and %s" % (who[0], who[1]), INFO)

    
if __name__ == "__main__":
    task()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Tests for ``moke.util``
"""
import unittest
import moke.util

class Test_core(unittest.TestCase):

    def test_import(self):
        assert moke.util.run_app

if __name__ == "__main__":
    unittest.main()


#!/usr/bin/env python2.7
from moke import *
import sys

@task
def fromdef_int(i=1):
    assert type(i) == int

@task
def fromdef_float(i=1.):
    assert type(i) == float

@task
def fromdef_path_r(i=stdin):
    assert type(i) == file
    assert i.mode == "rb"

@task
def fromdef_path_w(i=stdout):
    assert type(i) == file
    assert i.mode == "wb"

@task
def fromdoc_none_int(i=None):
    """
    -i(int) gets parsed!
    """
    assert type(i) == int
    
@task
def fromdoc_none_float(i=None):
    """
    -i(float) gets parsed!
    """
    assert type(i) == float  


@task
def fromdoc_pos_int(k):
    """General docs.
    -k(int) gets parsed!
    More general docs.
    """
    assert type(k) == int

@task
def fromdoc_pos_2(j, k):
    """General docs.
    -k(int) gets parsed!
    More general docs.
    """
    assert type(k) == int
    assert type(j) == str
    

@task
def none():
    pass

@task
def null():
    log("null called")

@task
def nulldoc():
    """
    """

@task
def justdoc():
    """ethio-jazz rules!
    for ever!
    """

@task
def nonedoc(j = None):
    """
    """

@task
def unktype(j = 1, zzz=17, a="Strrr"):
    """
    -j(sasalambada)
    """
    assert type(j) == int
    assert type(a) == str
    
@task
def iptopt(ipt=stdin, opt=stdout):
    #print ipt
    with ipt as ipt, opt as opt:
        for line in ipt:
            cols = line.strip().split("\t")
            opt.write("\t".join(cols[::-1]) + "\n")

@task
def filew(opt=stdout):
    """
    opt(file_w) A file to write
    """
    print repr(opt)


@task
def postype(a):
    """
    -a(int)
    """
    assert type(a) == int

@task
def deftype(a=7):
    """
    """
    assert type(a) == int


@task
def greet(who, shout=False, times=1):
    """
    Sends greetings from moke.
    
    -who(str2) two persons to greet
    -shout(switch) triggers CAPS
    
    """
    greetings = ("Hello %s and %s!\n" % (who[0], who[1])) * times
    if shout:
        greetings = greetings.upper()
    print greetings
    
if __name__ == "__main__":
    task()


#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
NAME = "moke"
VERSION = "1.1.4"

import setuptools
from distutils.core import setup

CLASSIFIERS = [
    "Development Status :: 4 - Beta",
    "Operating System :: OS Independent",
    "Intended Audience :: Developers",
    "Programming Language :: Python :: 2.7",
    "License :: OSI Approved :: BSD License"
    ]

setup(
    name=NAME.lower(),
    version=VERSION,
    description="moke is not like make",
    keywords="make, ant, rake, paver, build, shell, argparse, bash",
    author="Marcin Cieslik",
    author_email="mpc4p@virginia.edu",
    license="BSD License",
    long_description=open('README.rst', 'r').read(),
    classifiers=CLASSIFIERS,
    packages = ["moke"],
    package_dir = {"": "src"},
    package_data = {"moke": ["data/*"]},
    scripts = ["bin/moke"],
    # Options
    include_package_data=True,
    zip_safe=False,
    )



#!/usr/bin/env python2.7
from moke import *
import re

@task
def main(pattern, i=stdin, o=stdout, only_matching=False):
    """grop is not grep.
    """
    sre = re.compile(pattern)
    with i as i, o as o:
        for line in i:
            match = sre.match(line)
            if match:
                if only_matching:
                    o.write("%s\n" % match.groups()[0])
                else:
                    o.write(line)
    
if __name__ == "__main__":
    task()
